<h1>
    Meta Sass Module
    <br>
</h1>

<img align="right" alt="Logo" width="120" src="https://sass-lang.com/assets/img/logos/logo.svg">

<p>
    <img src="https://img.shields.io/npm/v/meta-sass-module"/>&nbsp;<img src="https://img.shields.io/npm/dm/meta-sass-module"/>&nbsp;<img src="https://img.shields.io/npm/l/meta-sass-module"/>
</p>
<p>
  <blockquote>Sass module provides more advanced meta functions</blockquote>
</p>

<h2>Install</h2>

Install the package:

```bash
npm i meta-sass-module
```

Use the package like any other Sass module:

```sass
@use "meta-sass-module"
```

Depending on your setup, you may need to configure `node_modules` as include path:

```javascript
const sass = require("sass");

sass.render({
  file: scss_filename,
  includePaths: ["node_modules"],
});
```

<h2>API</h2>

<h3>Mixins</h3>
<table>
    <thead>
        <tr>
            <th>#</th>
            <th>Name</th>
            <th>Description</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td>1</td>
            <td>
            <strong>Apply</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/mixins.md#apply"><code>meta-sass-module.apply($mixin, $args...)</code></a></small>
            </td>
            <td>Mixins can also be values! You can’t directly write a mixin as a value, but you can pass a mixin’s name to the <code>meta-sass-module.get-mixin()</code> function to get it as a value. Once you have a mixin value, you can pass it to the <code>meta-sass-module.apply()</code> mixin to call it. This is for libraries to be extensible in complex and powerful ways.</td>
        </tr>
        <tr>
            <td>2</td>
            <td>
            <strong>Load CSS</strong><br>
            <small><a href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/mixins.md#load-css"><code>meta-sass-module.load-css($url, $with: null)</code></a></small>
            </td>
            <td>Loads the module at $url and includes its CSS as though it were written as the contents of this mixin.</td>
        </tr>
    </tbody>
</table>

<h3>Functions</h3>
<table>
    <thead>
        <tr>
            <th>#</th>
            <th>Name</th>
            <th>Description</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td>1</td>
            <td>
            <strong>Accepts Content</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#accepts-content"><code>meta-sass-module.accepts-content($mixin)</code></a></small>
            </td>
            <td>Returns whether the given mixin value can accept a <code>@content</code> block.</td>
        </tr>
        <tr>
            <td>2</td>
            <td>
            <strong>Calculation Arguments</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#calc-args"><code>meta-sass-module.calc-args($calc)</code></a></small>
            </td>
            <td>Returns the arguments for the given calculation.</td>
        </tr>
        <tr>
            <td>3</td>
            <td>
            <strong>Calculation Name</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#calc-name"><code>meta-sass-module.calc-name($calc)</code></a></small>
            </td>
            <td>Returns the name for the given calculation.</td>
        </tr>
        <tr>
            <td>4</td>
            <td>
            <strong>Call</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#call"><code>meta-sass-module.call($function, $args...)</code></a></small>
            </td>
            <td>Invokes <code>$function</code> with <code>$args</code> and returns the result.</td>
        </tr>
        <tr>
            <td>5</td>
            <td>
            <strong>Content Exists</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#content-exists"><code>meta-sass-module.content-exists()</code></a></small>
            </td>
            <td>Returns whether the current mixin was passed a <code></code> block.</td>
        </tr>
        <tr>
            <td>6</td>
            <td>
            <strong>Feature Exists</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#feature-exists"><code>meta-sass-module.feature-exists($feature)</code></a></small>
            </td>
            <td>Returns whether the current Sass implementation supports <code>$feature</code>.</td>
        </tr>
        <tr>
            <td>7</td>
            <td>
            <strong>Function Exists</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#function-exists"><code>meta-sass-module.function-exists($name, $module: null)</code></a></small>
            </td>
            <td>Returns whether a function named <code>$name</code> is defined, either as a built-in function or a user-defined function.</td>
        </tr>
        <tr>
            <td>8</td>
            <td>
            <strong>Get Function</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#get-function"><code>meta-sass-module.get-function($name, $css: false, $module: null)</code></a></small>
            </td>
            <td>Returns the function value named <code>$name</code>.</td>
        </tr>
        <tr>
            <td>9</td>
            <td>
            <strong>Get Mixin</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#get-mixin"><code>meta-sass-module.get-mixin($name, $module: null)</code></a></small>
            </td>
            <td>Returns the mixin value named <code>$name</code>.</td>
        </tr>
        <tr>
            <td>10</td>
            <td>
            <strong>Global Variable Exists</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#global-variable-exists"><code>meta-sass-module.global-variable-exists($name, $module: null)</code></a></small>
            </td>
            <td>Returns whether a global variable named $name (without the $) exists.</td>
        </tr>
        <tr>
            <td>11</td>
            <td>
            <strong>Inspect</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#inspect"><code>meta-sass-module.inspect($value)s</code></a></small>
            </td>
            <td>Returns a string representation of <code>$value</code>.</td>
        </tr>
        <tr>
            <td>12</td>
            <td>
            <strong>Keywords</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#keywords"><code>meta-sass-module.keywords($args)</code></a></small>
            </td>
            <td>Returns the keywords passed to a mixin or function that takes arbitrary arguments. The <code>$args</code> argument must be an argument list.</td>
        </tr>
        <tr>
            <td>13</td>
            <td>
            <strong>Mixin Exists</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#mixin-exists"><code>meta-sass-module.mixin-exists($name, $module: null)</code></a></small>
            </td>
            <td>Returns whether a mixin named <code>$name</code> exists.</td>
        </tr>
        <tr>
            <td>14</td>
            <td>
            <strong>Module Functions</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#module-functions"><code>meta-sass-module.module-functions($module)</code></a></small>
            </td>
            <td>Returns all the functions defined in a module, as a map from function names to function values.</td>
        </tr>
        <tr>
            <td>15</td>
            <td>
            <strong>Module Mixins</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#module-mixins"><code>meta-sass-module.module-mixins($module)</code></a></small>
            </td>
            <td>Returns all the mixins defined in a module, as a map from mixin names to mixin values.</td>
        </tr>
        <tr>
            <td>16</td>
            <td>
            <strong>Module Variables</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#module-variables"><code>meta-sass-module.module-variables($module)</code></a></small>
            </td>
            <td>Returns all the variables defined in a module, as a map from variable names (without $) to the values of those variables.</td>
        </tr>
        <tr>
            <td>17</td>
            <td>
            <strong>Type of</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#type-of"><code>meta-sass-module.type-of($value)</code></a></small>
            </td>
            <td>Returns the type of <code>$value</code>. This can return the following values: number, string, color, list, map, calculation, bool, null, function, arglist</td>
        </tr>
        <tr>
            <td>18</td>
            <td>
            <strong>Variable Exists</strong><br>
            <small><a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#variable-exists"><code>meta-sass-module.variable-exists($name)</code></a></small>
            </td>
            <td>Returns whether a variable named <code>$name</code> (without the $) exists in the current scope.</td>
        </tr>
    </tbody>
</table>
