<img align="left" alt="logo" width="120" src="https://sass-lang.com/assets/img/logos/logo.svg" />
<h1>
    Mixins API | Math Sass Module
    <br>
    <small>
        <img alt="Dart Sass" src="https://img.shields.io/badge/Dart%20Sass-since%201.23.0-green"/>&nbsp;<img alt="LibSass" src="https://img.shields.io/badge/LibSass-%E2%9C%97-red"/>&nbsp;<img alt="Ruby Sass" src="https://img.shields.io/badge/Ruby%20Sass-%E2%9C%97-red"/>
    </small>
</h1>

<h2>apply</h2>

```sass
meta-sass-module.apply($mixin, $args...)
```

<p>Includes <code>$mixin</code> with <code>$args</code>. If this is passed a <a target="_blank" href="https://sass-lang.com/documentation/at-rules/mixin/#content-blocks"><code>@content</code> block</a>, it’s forwarded to <code>$mixin</code>.</p>
<p>The <code>$mixin</code> must be a <a target="_blank" href="https://sass-lang.com/documentation/values/mixins/">mixin value</a>, such as one returned by <a target="_blank" href="https://github.com/officialxviid/meta-sass-module/blob/main/docs/api/functions.md#get-mixin"><code>meta-sass-module.get-mixin()</code></a>.</p>

> **Sass**
>
> ```sass
> @use "meta-sass-module"
> @use "sass:string"
>
> /// Passes each element of $list to a separate invocation of $mixin.
> @mixin apply-to-all($mixin, $list)
>   @each $element in $list
>     @include meta-sass-module.apply($mixin, $element)
>
> @mixin font-class($size)
>   .font-#{$size}
>     font-size: $size
>
>
> $sizes: 8px, 12px 2rem
>
> @include apply-to-all(meta-sass-module.get-mixin("font-class"), $sizes)
> ```
>
> **CSS**
>
> ```css
> .font-8px {
>   font-size: 8px;
> }
>
> .font-12px {
>   font-size: 12px;
> }
>
> .font-2rem {
>   font-size: 2rem;
> }
> ```

<h2>load-css</h2>

```sass
meta-sass-module.load-css($url, $with: null)
```

<p>Loads the <a target="_blank" href="https://sass-lang.com/documentation/at-rules/use/">module</a> at <code>$url</code> and includes its CSS as though it were written as the contents of this mixin. The <code>$with</code> parameter provides <a target="_blank" href="https://sass-lang.com/documentation/at-rules/use/#configuration">configuration</a> for the modules; if it’s passed, it must be a map from variable names (without $) to the values of those variables to use in the loaded module.</p>
<p>If <code>$url</code> is relative, it’s interpreted as relative to the file in which <code>meta-sass-module.load-css()</code> is included.</p>
<p>
    <b>Like the <a target="_blank" href="https://sass-lang.com/documentation/at-rules/use/"><code>@use</code> rule</a>:</b>
    <ul>
        <li>This will only evaluate the given module once, even if it’s loaded multiple times in different ways.</li>
        <li>This cannot provide configuration to a module that’s already been loaded, whether or not it was already loaded with configuration.</li>
    </ul>
</p>
<p>
    <b>Unlike the <a target="_blank" href="https://sass-lang.com/documentation/at-rules/use/"><code>@use</code> rule</a>:</b>
    <ul>
        <li>This doesn’t make any members from the loaded module available in the current module.</li>
        <li>This can be used anywhere in a stylesheet. It can even be nested within style rules to create nested styles!</li>
        <li>The module URL being loaded can come from a variable and include <a target="_blank" href="https://sass-lang.com/documentation/interpolation/">interpolation</a>.</li>
    </ul>
</p>

> **Sass**
>
> ```sass
> // dark-theme/_code.sass
> $border-contrast: false !default
>
> code
>   background-color: #6b717f
>   color: #d2e1dd
>   @if $border-contrast
>       border-color: #dadbdf
> ```
>
> ```sass
> // style.sass
> @use "meta-sass-module"
>
> body.dark
>   $configuration: ("border-contrast": true)
>   @include meta-sass-module.load-css("dark-theme/code", $with: $configuration)
> ```
>
> **CSS**
>
> ```css
> body.dark code {
>   background-color: #6b717f;
>   color: #d2e1dd;
>   border-color: #dadbdf;
> }
> ```
